@@ -83,8 +83,6 @@ struct _Board {
 
   Vector placed_balls; /* temp for place_received_bubble() placed here to 
 			  avoid mallocation at each call and do not get into trouble due to parallelism */
-
-  int fixup_count; /* Recompute all ball position every 100 animations */
 };
 
 enum { 
@@ -95,7 +93,7 @@ enum {
 };
 
 
-void stick_bubble( Board board, Bubble bubble, int target_cell);
+void stick_bubble( Board board, Bubble bubble, int target);
 void drop_bubbles(Board board);
 void place_received_bubbles( Board board );
 
@@ -164,7 +162,6 @@ Board new_board( int period, RuleSet_t *ruleset, int mov_ceiling,
   board->period = period;
   board->nb_rising_bubbles = 0;
   board->placed_balls = vector_new( 10 );
-  board->fixup_count = 0;
 
   /* alert blinking light */
   board->alert = new_sprite( BOTTOM_LAYER, 30, alert_animation, 0, 0);
@@ -308,6 +305,7 @@ static void update_countdown( Board board, int dt ) {
 void explode_board( Board board ) {
   int i, clock;
   Bubble bubble;
+  float direction; /* direction of each bubble */
   /* sanity check */
   if (( board->state != LOST )&&
       ( board->state != WON )&&
@@ -326,12 +324,16 @@ void explode_board( Board board ) {
     /* now explode stuck bubbles and add a clock skew */
     clock = 0;
     for ( i = NB_CELLS-1; i >= 0; i-- )
+//    for ( i = 0 ; i < NB_CELLS-1; i++)
       if ( board->array->cell[i] != EMPTY_CELL ) {
 	bubble = board->array->cell[i];
-	bubble->vx = (rnd(100)-50)*EXPLODING_SPEED/10;
-	bubble->vy = -rnd(100)*EXPLODING_SPEED/100;
+	 
+	direction = ((float)rand())/((float)RAND_MAX+1.0) * 3.14159;
+	bubble->vx = cos(direction)*EXPLODING_SPEED*25;
+        bubble->vy = sin(direction)*EXPLODING_SPEED*25;
+
 	set_bubble_state( bubble, EXPLODING, TOP_LAYER, clock );
-	clock -= PROPAGATION_TIME;
+	 clock -= PROPAGATION_TIME;//*(i%COLS == 0? 20: 0);
       }
     cell_array_empty( board->array );
     board->state = WON;
@@ -342,13 +344,13 @@ void freeze_board( Board board ) {
   board->state = WON;
 }
 
-void stick_bubble( Board board, Bubble bubble, int target_cell) {
+void stick_bubble( Board board, Bubble bubble, int target) {
   double x, y;
-  cell_center( board->array, target_cell, &x, &y );
+  cell_center( board->array, target, &x, &y );
   set_bubble_state( bubble, STUCK, BOTTOM_LAYER, 0);
   set_bubble_position( bubble, x, y);
-  bubble->cell = target_cell;
-  board->array->cell[target_cell] = bubble;
+  bubble->cell = target;
+  board->array->cell[target] = bubble;
 }
 
 static void kill_bubble( Board board, Bubble bubble ) {
@@ -356,7 +358,7 @@ static void kill_bubble( Board board, Bubble bubble ) {
   remove_sprite_from_pool( board->sprite_pool, bubble->sprite );
 }
 
-int animate_bubbles( Board board, int dt ) {
+static int animate_bubbles( Board board, int dt ) {
   int i;
   Bubble tmp;
   Bubble bubble;
@@ -365,19 +367,6 @@ int animate_bubbles( Board board, int dt ) {
   int count;
   int transition_allowed = 1;
   double x, y, t;
-  if (board->fixup_count++ > 10) {
-    board->fixup_count = 0;
-    for (i=0; i<board->bubbles->size; i++) {
-       bubble = board->bubbles->element[0];
-       if (bubble->state == STUCK) {
-	  cell_center( board->array, bubble->cell, &x, &y );
-	  if (x != bubble->x || y != bubble->y) {
-	     warn("Fixup a ball!");
-	     set_bubble_position( bubble, x, y);
-	  }
-       }
-    }
-  }
    
   /* 
      possible board state transitions:
@@ -439,8 +428,9 @@ int animate_bubbles( Board board, int dt ) {
 	bubble->vx = board->vx[ board->canon_angle + CANON_ANGLE_MAX ];
 	bubble->vy = board->vy[ board->canon_angle + CANON_ANGLE_MAX ];
 	/* store target cell */
-	bubble->cell = target_cell( board->array, board->canon_angle+CANON_ANGLE_MAX, 
-				    &bubble->target_y,NULL );
+	bubble->cell = find_target_cell( board->array, 
+					 board->canon_angle+CANON_ANGLE_MAX, 
+					 &bubble->target_y,NULL );
 	transition_allowed = 0;
 	board->state = REBOUND;
 	board->launch_count++;
@@ -730,7 +720,7 @@ void drop_bubbles(Board board) {
    board->empty = cell_array_is_empty( board->array );
 }
 
-void lower_board(Board board) {
+static void lower_board(Board board) {
   int i, color;
   Bubble bubble;
 
@@ -761,7 +751,7 @@ void lower_board(Board board) {
 				  scale ));
 }
 
-void kill_board( Board board ) {
+static void kill_board( Board board ) {
   int i, clock;
   Bubble bubble;
   /* kill bubbles */
@@ -785,21 +775,19 @@ void kill_board( Board board ) {
 
 void canon_move( Board board, int dt ) {
   int frame, x, y;
-  Frame cframe;
   board->canon_virtual_angle += board->canon_direction*dt*CANON_ROTATING_SPEED*board->canon_speed;
   board->canon_virtual_angle = clip( board->canon_virtual_angle,
 				     -CANON_ANGLE_MAX, CANON_ANGLE_MAX );
   board->canon_angle = (int) floor( board->canon_virtual_angle + 0.5 );
   frame = (board->canon_angle+CANON_ANGLE_MAX)*canon_animation->size/NB_ANGLES;
   /* compute canon center coordinates */
-  cframe = (Frame) canon_animation->element[frame];
   x = scale_x( CANON_X, scale );
   y = scale_y( CANON_Y, scale );
   set_sprite_frame( board->canon_sprite, frame);
   set_sprite_position( board->canon_sprite, x, y);
 }
 
-void animate_alert( Board board ) {
+static void animate_alert( Board board ) {
   int blinking;
   /* blink alert when launch count is almost equal to period */
   if ( board->launch_count >= board->period - 1 ) {
@@ -862,7 +850,7 @@ void animate_board( Board board, int dt ) {
 
 void canon_rotate_left( Board board ) {
   if (board->canon_direction == -1)
-    board->canon_speed += MIN( (5-board->canon_speed)/10, 0.1 );
+    board->canon_speed += MIN( (5-board->canon_speed)/10, 0.2 );
   else
     board->canon_speed=1;
   board->canon_direction = -1;
@@ -870,7 +858,7 @@ void canon_rotate_left( Board board ) {
 
 void canon_rotate_right( Board board ) {
   if (board->canon_direction == 1)
-    board->canon_speed += MIN( (5-board->canon_speed)/10, 0.1 );
+    board->canon_speed += MIN( (5-board->canon_speed)/10, 0.2 );
   else
     board->canon_speed=1;
   board->canon_direction = 1;
@@ -883,7 +871,7 @@ void canon_stop( Board board ) {
 
 void canon_fire(Board board) {
   board->launch_requested = 1;
-  board->canon_speed = 1;
+  canon_stop(board);
 }
 
 SpritePool get_board_sprite_pool( Board board ) {
