@@ -2,7 +2,7 @@
   XBubble - cell.c
  
   Copyright (C) 2002  Ivan Djelic <ivan@savannah.gnu.org>
-  Copyright (C) 2003  Martin Quinson <mquinson@savannah.gnu.org>
+  Copyright (C) 2003  Martin Quinson (mquinson::debian.org)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -251,7 +251,7 @@ int find_random_empty_cell( CellArray ca, int from_top ) {
 
 extern int xbubble_path_cache[2][ROWS][NB_ANGLES][2][TRAJ_MAX_LENGTH];
 
-int target_cell( CellArray ca, int angle, 
+int find_target_cell( CellArray ca, int angle, 
 		 double *target_y, /* upper bound to the ball animation */
 		 Vector outpath /* used in player vs computer mode (cf opponent.c)*/ ) {
 
@@ -297,7 +297,7 @@ int target_cell( CellArray ca, int angle,
   return OUT_OF_BOUNDS;
 }
 
-void hook_cell( CellArray ca, int i) {
+static void hook_cell( CellArray ca, int i) {
   Quadrant q;
   if (( cell_not_empty( ca, i))&&( ! ca->tagged[i] )) {
     ca->tagged[i] = 1;
@@ -468,7 +468,7 @@ int count_reacting_bubbles( CellArray ca,
 }
 #endif
 
-void dump_array(CellArray ca) {
+static void dump_array(CellArray ca) {
   int i, j, k;
 
   printf("_________________________________\n");
