@@ -52,10 +52,10 @@ int  cell_array_is_overflow( CellArray ca );
 int cellCL( CellArray ca, int row, int col );
 int floating_cell( CellArray ca, int c );
 void cell_center( CellArray ca, int cell, double *x, double *y);
-int target_cell( CellArray ca, 
-		 int angle, 
-		 double * target_y,
-		 Vector path );
+int find_target_cell( CellArray ca, 
+		      int angle, 
+		      double * target_y,
+		      Vector path );
 
 int find_random_empty_cell( CellArray ca, int from_top  );
 
