@@ -4,7 +4,7 @@
 #include <X11/Xlib.h>
 
 void get_column_size( int nb_lines,
-		      char ** line,
+		      const char ** line,
 		      XFontStruct *xfont,
 		      int *width,
 		      int *height );
@@ -12,27 +12,27 @@ void get_column_size( int nb_lines,
 Window create_column( int x,
 		      int y,
 		      int nb_lines,
-		      char ** line, 
+		      const char ** line, 
 		      XFontStruct *xfont,
 		      unsigned long *pixel,
 		      double expand );
 
 Window create_dialog( int x,
 		      int y,
-		      char * msg,
+		      const char * msg,
 		      XFontStruct *xfont, 
 		      unsigned long pixel,
 		      int border_width,
 		      double expand );
 
 void get_menu_size( int nb_entries,
-		    char ** entries,
+		    const char ** entries,
 		    int *width,
 		    int *height,
 		    int horizontal );
 
 void get_menu_choices( int nb_entries,
-		       char ** entries,
+		       const char ** entries,
 		       int *x,
 		       int *y, 
 		       int *selection,
