@@ -4,8 +4,14 @@
 #include <X11/Xlib.h>
 
 typedef struct _Frame {
-  int width, height, cx, cy, delay, has_mask;
-  Pixmap pixmap, mask;
+  int width;
+  int height;
+  int cx;
+  int cy;
+  int delay;
+  int has_mask;
+  Pixmap pixmap;
+  GC gc;
 } * Frame;
 
 #endif /* _FRAME_H */
