@@ -2,5 +2,7 @@
 #define _LOADPNG_H
 
 unsigned char * load_png_file( const char *filename, 
-			       int *width, int *height, int *has_alpha );
+			       int *width,
+			       int *height,
+			       int *has_alpha );
 #endif /* _LOADPNG_H */
