@@ -229,7 +229,7 @@ static void compute_targets( Opponent op, int depth ) {
     /* full target cell computation for each angle */
     for ( i = 0; i < NB_ANGLES; i++ ) {
       angle = (i/2)*(1-2*(i%2)) + CANON_ANGLE_MAX;
-      target = target_cell( op->array, angle, NULL, op->path[angle] );
+      target = find_target_cell( op->array, angle, NULL, op->path[angle] );
       /* store target cell */
       op->target[angle] = target;
       /* make targets vector for searching */
@@ -282,7 +282,7 @@ static void compute_targets( Opponent op, int depth ) {
 	  }
 	}
       if ( target_invalid )
-	target = target_cell( op->array, angle, NULL, NULL );
+	target = find_target_cell( op->array, angle, NULL, NULL );
       /* make targets vector for searching */
       if ( ! cell_cache[target] ) {
 	cell_cache[target] = 1;
