@@ -4,14 +4,18 @@
 #include "board.h"
 
 typedef struct _Opponent * Opponent;
-enum Level { VERY_EASY, EASY, NORMAL, HARD, VERY_HARD };
+
+enum Level {
+  VERY_EASY,
+  EASY,
+  NORMAL,
+  HARD,
+  VERY_HARD
+};
 
 Opponent new_opponent( Board board, int level );
-void reset_opponent( Opponent op, Board board );
 void delete_opponent( Opponent opponent );
-int find_best_angle( Opponent op );
-int get_best_angle( Opponent op );
-int get_best_eval( Opponent op );
+int find_best_angle( Opponent op, int *best_eval );
 
 #endif /* _OPPONENT_H */
 
