@@ -17,8 +17,9 @@ RgbaImage new_rgba_image( int width, int height );
 void delete_rgba_image( RgbaImage ri );
 
 RgbaImage create_rgba_image_from_png_file( const char *filename );
+RgbaImage copy_rgba_image( RgbaImage ri );
 RgbaImage scale_rgba_image( RgbaImage ri, double scalex, double scaley );
-RgbaImage crop_rgba_image( RgbaImage ri, int x1, int y1, int x2, int y2 );
+RgbaImage crop_rgba_image( RgbaImage ri, int x1_arg, int y1_arg, int x2_arg, int y2_arg );
 RgbaImage rotate_rgba_image( RgbaImage ri, double angle, int autocrop );
 
 void create_pixmaps_from_rgba_image( RgbaImage ri, Pixmap *rgb, Pixmap *mask);
