@@ -10,6 +10,7 @@ enum ScreenMain_Choice {
   S1_PLAYER_VS_COMPUTER,
   S1_CHALLENGE,
   S1_DEMO,
+  S1_SETTINGS,
   S1_QUIT
 };
 
@@ -41,10 +42,22 @@ enum handicap_1p_Choice {
   S5_4
 };
 
-enum ScreenMain_Choice screen_main();
-enum ScreenComputerSkill_Choice screen_computer_skill();
+enum ScreenSettings_Choice {
+  S6_ESCAPE = -1,
+  S6_KEY,
+  S6_CANON,
+  S6_THEME,
+  S6_BACK
+};
+
+enum ScreenMain_Choice screen_main(enum ScreenMain_Choice preset);
+enum ScreenComputerSkill_Choice screen_computer_skill(void);
 enum Screen2p_Choice screen_2p( enum GameMode mode, int *rounds, int *games );
 enum handicap_2p_Choice screen_2p_handicap( int *choice );
-enum handicap_1p_Choice screen_1p_handicap();
+enum handicap_1p_Choice screen_1p_handicap(void);
+
+enum ScreenSettings_Choice screen_settings(enum ScreenSettings_Choice preset);
+  
+void screen_unimplemented(void);
 
 #endif /* _SCREENS_H */
