@@ -2,7 +2,7 @@
   XBubble - utils.c
 
   Copyright (C) 2002  Ivan Djelic <ivan@savannah.gnu.org>
-  Copyright (C) 2003  Martin Quinson <mquinson@savannah.gnu.org>
+  Copyright (C) 2003  Martin Quinson (mquinson::debian.org)
   
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -79,6 +79,7 @@ Set set_new( int max_size ) {
   s->element = (void **) xmalloc( sizeof(void *) * max_size);
   s->max_size = max_size;
   s->size = 0;
+  s->ref = 1;
   return s;
 }
 
@@ -89,6 +90,17 @@ void set_free( Set s ) {
   }
 }
 
+void set_ref(Set set) {
+  set->ref++;
+}
+
+void set_unref(Set set) {
+  if (!--set->ref) {
+     set_free(set);
+  }
+}
+
+   
 void set_add( Set s, void * p ) {
   if ( s->size >= s->max_size ) {
     s->max_size += SET_BLOCK;
