@@ -80,7 +80,8 @@ static void play_single_player_game( int *handicap ) {
   Game game;
 
   ruleset.max_fire_delay = handicap[0];
-  for ( i = 0; again && i < nb_levels; won && i++ ) {    
+  i=0;
+  while (again && i < nb_levels) {
     game = new_game( SINGLE_PLAYER, &ruleset, levels[i], i+1, 
 		     score, NORMAL );
     
@@ -88,6 +89,7 @@ static void play_single_player_game( int *handicap ) {
     won = ( result == PLAYER1_WON );
     again = ( result != ABORTED );
     delete_game( game, again && ( !won || ( i+1 < nb_levels )));
+    if (won) i++;
   }
   if ( won )
     printf(_("CONGRATULATIONS !!!\n"));
